@@ -16,7 +16,9 @@ Usage::
     session_client: SSOOIDCClient = session.client("sso-oidc")
     ```
 """
-from mypy_boto3_sso_oidc.client import SSOOIDCClient as Client, SSOOIDCClient
+from mypy_boto3_sso_oidc.client import SSOOIDCClient
+
+Client = SSOOIDCClient
 
 
 __all__ = ("Client", "SSOOIDCClient")
